PyXMake Developer Guide: Packages

| PyXMake Developer Guide 1.0 PyXMake

Packages
Here are the packages with brief descriptions (if available):
[detail level 123]

▼N PyXMake | PyXMake package for programmable build events on Linux and Windows
▼N Build | Module containing all relevant modules and scripts associated with the building process
N __install__ | Fetch 3rd party dependencies for PyXMake from DLR's resource server
N Make | Create a make object to define the building environment
▼N Tools | Module containing basic functionalities defined for convenience
N ErrorHandling | Error handling module
N Utility | Module of basic functions
▼N VTL | Module containing virtual testing & benchmark scripts
N abaqus |
N api |
N app |
N bundle |
N cxx |
N doxygen |
N ifort |
N java |
N py2x |
N sphinx |
N ssh_f2py |
N ssh_ifort |
N ssh_make |
N stm_make | Start build jobs on the Jenkins Test Server using PyXMake